@@ -490,19 +490,71 @@ class opensshStatus(StatusMenuItem):
         if sshNetstat[0] == "":
             sshNetstat = []
         
+        #countInWLAN = 0
+        #countOutWLAN = 0
+        #if self.wlanIP != "None":
+        #    countAllWLAN = 0
+        #    for line in sshNetstat:
+        #        if self.wlanIP in line:
+        #            countAllWLAN += 1
+        #    if countAllWLAN:
+        #        for line in sshNetstat:
+        #            element = " ".join(line.split()).split()[3]
+        #            if self.wlanIP + ":ssh" in element:
+        #                countInWLAN += 1
+        #    countOutWLAN = countAllWLAN - countInWLAN
+        #    if countInWLAN != self.labelCountInWLAN:
+        #        self.labelCountInWLAN = countInWLAN
+        #        self.labelInWLAN.set_label(str(countInWLAN) + "  WLAN")
+        #    if countOutWLAN != self.labelCountOutWLAN:
+        #        self.labelCountOutWLAN = countOutWLAN
+        #        self.labelOutWLAN.set_label(str(countOutWLAN) + "  WLAN")
+        #else:
+        #    self.labelInWLAN.set_label("?  WLAN")
+        #    self.labelOutWLAN.set_label("?  WLAN")
+        #
+        #countInUSB = 0
+        #countOutUSB = 0
+        #if self.usbIP != "None":
+        #    countAllUSB = 0
+        #    for line in sshNetstat:
+        #        if self.usbIP in line:
+        #            countAllUSB += 1
+        #    if countAllUSB:
+        #        for line in sshNetstat:
+        #            element = " ".join(line.split()).split()[3]
+        #            if self.usbIP + ":ssh" in element:
+        #                countInUSB += 1
+        #    countOutUSB = countAllUSB - countInUSB
+        #    if countInUSB != self.labelCountInUSB:
+        #        self.labelCountInUSB = countInUSB
+        #        self.labelInUSB.set_label(str(countInUSB) + "  USB")
+        #    if countOutUSB != self.labelCountOutUSB:
+        #        self.labelCountOutUSB = countOutUSB
+        #        self.labelOutUSB.set_label(str(countOutUSB) + "  USB")
+        #else:
+        #    self.labelInUSB.set_label("?  USB")
+        #    self.labelOutUSB.set_label("?  USB")
+        
         countInWLAN = 0
         countOutWLAN = 0
+        countAllWLAN = 0
+        countInUSB = 0
+        countOutUSB = 0
+        countAllUSB = 0
+        for line in sshNetstat:
+            if self.wlanIP in line:
+                countAllWLAN += 1
+            if self.usbIP in line:
+                countAllUSB += 1
+            element = " ".join(line.split()).split()[3]
+            if self.wlanIP + ":ssh" in element:
+                countInWLAN += 1
+            if self.usbIP + ":ssh" in element:
+                countInUSB += 1
+        countOutWLAN = countAllWLAN - countInWLAN
+        countOutUSB = countAllUSB - countInUSB
         if self.wlanIP != "None":
-            countAllWLAN = 0
-            for line in sshNetstat:
-                if self.wlanIP in line:
-                    countAllWLAN += 1
-            if countAllWLAN:
-                for line in sshNetstat:
-                    element = " ".join(line.split()).split()[3]
-                    if self.wlanIP + ":ssh" in element:
-                        countInWLAN += 1
-            countOutWLAN = countAllWLAN - countInWLAN
             if countInWLAN != self.labelCountInWLAN:
                 self.labelCountInWLAN = countInWLAN
                 self.labelInWLAN.set_label(str(countInWLAN) + "  WLAN")
@@ -510,22 +562,11 @@ class opensshStatus(StatusMenuItem):
                 self.labelCountOutWLAN = countOutWLAN
                 self.labelOutWLAN.set_label(str(countOutWLAN) + "  WLAN")
         else:
+            self.labelCountInWLAN = -1
+            self.labelCountOutWLAN = -1
             self.labelInWLAN.set_label("?  WLAN")
             self.labelOutWLAN.set_label("?  WLAN")
-        
-        countInUSB = 0
-        countOutUSB = 0
         if self.usbIP != "None":
-            countAllUSB = 0
-            for line in sshNetstat:
-                if self.usbIP in line:
-                    countAllUSB += 1
-            if countAllUSB:
-                for line in sshNetstat:
-                    element = " ".join(line.split()).split()[3]
-                    if self.usbIP + ":ssh" in element:
-                        countInUSB += 1
-            countOutUSB = countAllUSB - countInUSB
             if countInUSB != self.labelCountInUSB:
                 self.labelCountInUSB = countInUSB
                 self.labelInUSB.set_label(str(countInUSB) + "  USB")
@@ -533,6 +574,8 @@ class opensshStatus(StatusMenuItem):
                 self.labelCountOutUSB = countOutUSB
                 self.labelOutUSB.set_label(str(countOutUSB) + "  USB")
         else:
+            self.labelCountInUSB = -1
+            self.labelCountOutUSB = -1
             self.labelInUSB.set_label("?  USB")
             self.labelOutUSB.set_label("?  USB")
         
@@ -543,19 +586,19 @@ class opensshStatus(StatusMenuItem):
         if countOutOther < 0:
             countOutOther = 0
         
-        if countInOther:
-            if countInOther != self.labelCountInOther:
-                self.labelCountInOther = countInOther
+        if countInOther != self.labelCountInOther:
+            self.labelCountInOther = countInOther
+            if countInOther:
                 self.labelInOther.set_label(str(countInOther) + "  Other")
-        else:
-            self.labelInOther.set_label("")
+            else:
+                self.labelInOther.set_label("")
             
-        if countOutOther:
-            if countOutOther != self.labelCountOutOther:
-                self.labelCountOutOther = countOutOther
+        if countOutOther != self.labelCountOutOther:
+            self.labelCountOutOther = countOutOther
+            if countOutOther:
                 self.labelOutOther.set_label(str(countOutOther) + "  Other")
-        else:
-            self.labelOutOther.set_label("")
+            else:
+                self.labelOutOther.set_label("")
             
     def sshTracker(self):
         if self.trackingEnabled:
@@ -1081,17 +1124,23 @@ class opensshStatus(StatusMenuItem):
         
         countInWLAN = 0
         countOutWLAN = 0
+        countAllWLAN = 0
+        countInUSB = 0
+        countOutUSB = 0
+        countAllUSB = 0
+        for line in sshNetstat:
+            if self.wlanIP in line:
+                countAllWLAN += 1
+            if self.usbIP in line:
+                countAllUSB += 1
+            element = " ".join(line.split()).split()[3]
+            if self.wlanIP + ":ssh" in element:
+                countInWLAN += 1
+            if self.usbIP + ":ssh" in element:
+                countInUSB += 1
+        countOutWLAN = countAllWLAN - countInWLAN
+        countOutUSB = countAllUSB - countInUSB
         if self.wlanIP != "None":
-            countAllWLAN = 0
-            for line in sshNetstat:
-                if self.wlanIP in line:
-                    countAllWLAN += 1
-            if countAllWLAN:
-                for line in sshNetstat:
-                    element = " ".join(line.split()).split()[3]
-                    if self.wlanIP + ":ssh" in element:
-                        countInWLAN += 1
-            countOutWLAN = countAllWLAN - countInWLAN
             self.labelCountInWLAN = countInWLAN
             self.labelCountOutWLAN = countOutWLAN
             self.labelInWLAN.set_label(str(countInWLAN) + "  WLAN")
@@ -1101,30 +1150,17 @@ class opensshStatus(StatusMenuItem):
             self.labelCountOutWLAN = -1
             self.labelInWLAN.set_label("?  WLAN")
             self.labelOutWLAN.set_label("?  WLAN")
-        
-        countInUSB = 0
-        countOutUSB = 0
         if self.usbIP != "None":
-            countAllUSB = 0
-            for line in sshNetstat:
-                if self.usbIP in line:
-                    countAllUSB += 1
-            if countAllUSB:
-                for line in sshNetstat:
-                    element = " ".join(line.split()).split()[3]
-                    if self.usbIP + ":ssh" in element:
-                        countInUSB += 1
-            countOutUSB = countAllUSB - countInUSB
-            self.labelCountInUSB = countInUSB
-            self.labelCountOutUSB = countOutUSB
-            self.labelInUSB.set_label(str(countInUSB) + "  USB")
-            self.labelOutUSB.set_label(str(countOutUSB) + "  USB")
+                self.labelCountInUSB = countInUSB
+                self.labelCountOutUSB = countOutUSB
+                self.labelInUSB.set_label(str(countInUSB) + "  USB")
+                self.labelOutUSB.set_label(str(countOutUSB) + "  USB")
         else:
             self.labelCountInUSB = -1
             self.labelCountOutUSB = -1
             self.labelInUSB.set_label("?  USB")
             self.labelOutUSB.set_label("?  USB")
-            
+        
         countInOther = self.sshConnected - countInWLAN - countInUSB
         countOutOther = len(sshNetstat) - self.sshConnected - countOutWLAN - countOutUSB
         if countInOther < 0:
